@@ -1,5 +1,5 @@
 package Dist::Zilla::PluginBundle::RJBS;
-our $VERSION = '0.100500';
+our $VERSION = '0.100650';
 # ABSTRACT: BeLike::RJBS when you build your dists
 
 use Moose;
@@ -18,7 +18,7 @@ sub bundle_config {
   my $is_task = $arg->{task};
 
   my @plugins = Dist::Zilla::PluginBundle::Filter->bundle_config({
-    name    => "$class/Classic",
+    name    => $section->{name} . '/@Classic',
     payload => {
       bundle => '@Classic',
       remove => [ qw(PodVersion) ],
@@ -40,7 +40,7 @@ sub bundle_config {
   }
 
   my $prefix = 'Dist::Zilla::Plugin::';
-  my @extra = map {[ "$class/$prefix$_->[0]" => "$prefix$_->[0]" => $_->[1] ]}
+  my @extra = map {[ "$section->{name}/$_->[0]" => "$prefix$_->[0]" => $_->[1] ]}
   (
     [ AutoPrereq  => {} ],
     [
@@ -59,7 +59,7 @@ sub bundle_config {
   push @plugins, @extra;
 
   push @plugins, Dist::Zilla::PluginBundle::Git->bundle_config({
-    name    => "$class/Git",
+    name    => "$section->{name}/\@Git",
     payload => {
       tag_format => '%v',
     },
@@ -81,7 +81,7 @@ Dist::Zilla::PluginBundle::RJBS - BeLike::RJBS when you build your dists
 
 =head1 VERSION
 
-version 0.100500
+version 0.100650
 
 =head1 DESCRIPTION
 
